@@ -1,8 +1,5 @@
 package Data::Section::Seekable::Writer;
 
-our $DATE = '2016-02-19'; # DATE
-our $VERSION = '0.09'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -11,6 +8,11 @@ use overload
     '""'  => 'as_string',
     ;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-01-20'; # DATE
+our $DIST = 'Data-Section-Seekable'; # DIST
+our $VERSION = '0.091'; # VERSION
+
 sub new {
     my $class = shift;
 
@@ -89,7 +91,7 @@ Data::Section::Seekable::Writer - Generate data section with multiple parts
 
 =head1 VERSION
 
-This document describes version 0.09 of Data::Section::Seekable::Writer (from Perl distribution Data-Section-Seekable), released on 2016-02-19.
+This document describes version 0.091 of Data::Section::Seekable::Writer (from Perl distribution Data-Section-Seekable), released on 2023-01-20.
 
 =head1 SYNOPSIS
 
@@ -159,6 +161,11 @@ Get/set header attribute.
 
 Empty content.
 
+=head2 Why am I getting the error message "readline() on unopened filehandle DATA at ..."?
+
+You are probably writing in the BEGIN phase, at which point the DATA filehandle
+is not available. Read L<perldata> for more details.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Section-Seekable>.
@@ -167,14 +174,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Secti
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Section-Seekable>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Section-Seekable>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Data::Section::Seekable> for the description of the data format.
@@ -185,11 +184,37 @@ L<Data::Section::Seekable::Reader> for the reader class.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Section-Seekable>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
